summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>2003-10-05 15:35:27 +0000
committerJim Meyering <jim@meyering.net>2003-10-05 15:35:27 +0000
commit77549cb5c3abe3c356c306d788740cd383b92545 (patch)
treea1f4bffef001dc96cfeab50f109aff46ba498733 /src
parent64396834335276a53206d2dc1600e0f4f65d32ce (diff)
downloadcoreutils-77549cb5c3abe3c356c306d788740cd383b92545.tar.xz
s/nftw/fts/g in a comment
Diffstat (limited to 'src')
-rw-r--r--src/du.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/du.c b/src/du.c
index 989753d33..c48477cba 100644
--- a/src/du.c
+++ b/src/du.c
@@ -285,8 +285,8 @@ print_size (uintmax_t n_bytes, const char *string)
fflush (stdout);
}
-/* This function is called once for every file system object that nftw
- encounters. nftw does a depth-first traversal. This function knows
+/* This function is called once for every file system object that fts
+ encounters. fts does a depth-first traversal. This function knows
that and accumulates per-directory totals based on changes in
the depth of the current entry. */